@@ -1,9 +1,9 @@
-"""SQL query filter strategy"""
+"""SQL query filter strategy."""
 # pylint: disable=unused-argument
 from dataclasses import dataclass
 from typing import TYPE_CHECKING
 
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 
 from oteapi.plugins import StrategyFactory
 
@@ -14,12 +14,21 @@ if TYPE_CHECKING:
 
 
 class SqlQueryDataModel(BaseModel):
-    query: str
+    """SQL Query data model."""
+
+    query: str = Field(..., description="A SQL query string.")
 
 
 @dataclass
 @StrategyFactory.register(("filterType", "filter/sql"))
 class SQLQueryFilter:
+    """Strategy for a SQL query filter.
+
+    **Registers strategies**:
+
+    - `("filterType", "filter/sql")`
+
+    """
 
     filter_config: "FilterConfig"
 
