@@ -14,15 +14,23 @@ if TYPE_CHECKING:
 @dataclass
 @StrategyFactory.register(("mediaType", "text/csv"))
 class CSVParseStrategy:
+    """Parse strategy for CSV files.
+
+    **Registers strategies**:
+
+    - `("mediaType", "text/csv")`
+
+    """
 
     resource_config: "ResourceConfig"
 
     def parse(self, session: "Optional[Dict[str, Any]]" = None) -> "Dict[str, Any]":
+        """Parse CSV."""
         print("CSV in action!")
         return {}
 
     def initialize(
         self, session: "Optional[Dict[str, Any]]" = None
     ) -> "Dict[str, Any]":
-        """Initialize"""
+        """Initialize."""
         return {}
